from holehe.core import *
from holehe.localuseragent import *


async def adobe(email, client, out):
    name = "adobe"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Accept': 'application/json, text/plain, */*',
        'Accept-Language': 'en-US,en;q=0.5',
        'X-IMS-CLIENTID': 'adobedotcom2',
        'Content-Type': 'application/json;charset=utf-8',
        'Origin': 'https://auth.services.adobe.com',
        'DNT': '1',
        'Connection': 'keep-alive',
    }

    data = '{"username":"' + email + '","accountType":"individual"}'
    r = await client.post(
        'https://auth.services.adobe.com/signin/v1/authenticationstate',
        headers=headers,
        data=data)
    r = r.json()
    if "errorCode" in str(r.keys()):
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None
    headers['X-IMS-Authentication-State'] = r['id']
    params = {
        'purpose': 'passwordRecovery',
    }
    response = await client.get(
        'https://auth.services.adobe.com/signin/v2/challenges',
        headers=headers,
        params=params)
    response=response.json()
    out.append({"name": name,
                "rateLimit": False,
                "exists": True,
                "emailrecovery": response['secondaryEmail'],
                "phoneNumber": response['securityPhoneNumber'],
                "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def tellonym(email, client, out):
    name = "tellonym"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["firefox"]),
        'Accept': 'application/json',
        'Accept-Language': 'en,en-US;q=0.5',
        'tellonym-client': 'web:0.51.1',
        'content-type': 'application/json;charset=utf-8',
        'Origin': 'https://tellonym.me',
        'Connection': 'keep-alive',
        'Referer': 'https://tellonym.me/register/email',
        'TE': 'Trailers',
    }

    params = {
        'email': str(email),
        'errorMessage': '',
        'limit': '25',
    }

    try:
        response = await client.get('https://api.tellonym.me/accounts/check', headers=headers, params=params)
        if "EMAIL_ALREADY_IN_USE" in response.text:
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        else:
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
    except BaseException:
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def evernote(email, client, out):
    name = "evernote"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["firefox"]),
        'Accept': 'application/json, text/javascript, */*; q=0.01',
        'Accept-Language': 'en,en-US;q=0.5',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'X-Requested-With': 'XMLHttpRequest',
        'Origin': 'https://www.evernote.com',
        'DNT': '1',
        'Connection': 'keep-alive',
        'Referer': 'https://www.evernote.com/Login.action',
        'TE': 'Trailers',
    }
    data = await client.get("https://www.evernote.com/Login.action", headers=headers)
    data2 = {
        'username': email, 'evaluateUsername': '',
        'hpts': data.text.split('document.getElementById("hpts").value = "')
        [1].split('"')[0],
        'hptsh': data.text.split('document.getElementById("hptsh").value = "')
        [1].split('"')[0],
        'analyticsLoginOrigin': 'login_action', 'clipperFlow': 'false',
        'showSwitchService': 'true', 'usernameImmutable': 'false',
        '_sourcePage': data.text.split(
            '<input type="hidden" name="_sourcePage" value="')[1].split('"')
        [0],
        '__fp': data.text.split('<input type="hidden" name="__fp" value="')
        [1].split('"')[0]}
    response = await client.post('https://www.evernote.com/Login.action', data=data2, headers=headers)
    if "usePasswordAuth" in response.text:
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    elif "displayMessage" in response.text:
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def atlassian(email, client, out):
    name = "atlassian"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Accept': '*/*',
        'Accept-Language': 'en,en-US;q=0.5',
        'Referer': 'https://id.atlassian.com/',
        'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
        'Origin': 'https://id.atlassian.com',
        'DNT': '1',
        'Connection': 'keep-alive',
    }
    try:
        r = await client.get("https://id.atlassian.com/login", headers=headers)
        data = {'csrfToken': r.text.split('{&quot;csrfToken&quot;:&quot;')[
            1].split('&quot')[0], 'username': email}
    except :
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    response = await client.post('https://id.atlassian.com/rest/check-username', headers=headers, data=data)
    if response.json()["action"] == "signup":
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def laposte(email, client, out):
    name = "laposte"
    headers = {
        'Origin': 'https://www.laposte.fr',
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
        'Referer': 'https://www.laposte.fr/authentification',
        'Accept-Language': 'fr-FR,fr;q=0.9,en-US;q=0.8,en;q=0.7',
    }

    data = {
        'email': email,
        'customerId': '',
        'tunnelSteps': ''
    }

    response = await client.post('https://www.laposte.fr/authentification', headers=headers, data=data)
    post_soup = BeautifulSoup(response.content, 'html.parser')
    l = post_soup.find_all('span', id="wrongEmail")
    out.append({"name": name,
                "rateLimit": False,
                "exists": l != [],
                "emailrecovery": None,
                "phoneNumber": None,
                "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def ebay(email, client, out):
    name = "ebay"

    headers = {
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Accept': 'application/json, text/plain, */*',
        'Accept-Language': 'en-US,en;q=0.5',
        'Origin': 'https://www.ebay.com',
        'DNT': '1',
        'Connection': 'keep-alive',
    }
    try:
        req = await client.get(
            "https://www.ebay.com/signin/", headers=headers)
        srt = req.text.split('"csrfAjaxToken":"')[1].split('"')[0]
    except IndexError:
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    data = {
        'identifier': email,
        'srt': srt
    }

    req = await client.post(
        'https://signin.ebay.com/signin/srv/identifer',
        data=data, headers=headers)
    results = json.loads(req.text)
    if "err" in results.keys():
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        out.append({"name": name,
                    "rateLimit": False,
                    "exists": True,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
